package kieker.webgui.beans.session;

import java.util.Map;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.context.FacesContext;

import kieker.webgui.beans.application.ThemeSwitcherBean;

/**
 * This bean can be used for a single session of a user and stores the currently used theme (look and feel) for this user. Currently the default value being used is
 * the "glass-x"-theme, if none is find within the parameters of the faces context.
 * 
 * @author Nils Christian Ehmke
 * 
 * @see ThemeSwitcherBean
 */
@ManagedBean
@SessionScoped
public class CurrentThemeBean {

	private static final String DEFAULT_THEME = "glass-x";
	private String theme;

	/**
	 * Creates a new instance of this class.
	 */
	public CurrentThemeBean() {
		/* Get the parameters within the current context. */
		Map<String, String> params = FacesContext.getCurrentInstance().getExternalContext().getRequestParameterMap();
		/* Try to find the default theme. */
		if (params.containsKey("theme")) {
			theme = params.get("theme");
		} else {
			/* Use the default theme. */
			theme = DEFAULT_THEME;
		}
	}

	/**
	 * Delivers the current theme.
	 * 
	 * @return The currently used theme.
	 */
	public String getTheme() {
		return theme;
	}

	/**
	 * Sets the value of this bean.
	 * 
	 * @param theme
	 *            The new theme to be stored within this instance.
	 */
	public void setTheme(String theme) {
		this.theme = theme;
	}
}
